font-v
========

The font-v executable and the libfv library support reads, reporting, modification, and writes of OpenType name table nameID 5 (version string) records in .ttf and .otf fonts.

Source and documentation: https://github.com/source-foundry/font-v

libfv API documentation: https://font-v.readthedocs.io/en/latest/

Issue reporting: https://github.com/source-foundry/font-v/issues

License: MIT
